@@ -3,6 +3,6 @@
 #' Helper functions for making using ggplot2 easier.
 #'
 #' @name ggeasy
+#' @keywords internal
 #' @import ggplot2
-#' @docType package
-NULL
+"_PACKAGE"
